==> haskell-servant-swagger-1.1.5-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.5
id: servant-swagger-1.1.5-DiRxc2kNiQzECxFkHDCxYv
key: servant-swagger-1.1.5-DiRxc2kNiQzECxFkHDCxYv
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger™ is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 5e758e4511f03d3adea4ed82c8b169ca
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-swagger-1.1.5
hs-libraries: HSservant-swagger-1.1.5-DiRxc2kNiQzECxFkHDCxYv
depends:
    aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b base-4.11.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-Frbrz52X4fNB7jXswOZzbv
    lens-4.17-9Q1pWD2BrerLhuespF4bwK
    servant-0.13.0.1-G69gaOSA7cz7Xz442jerNe
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    swagger2-2.2.2-7J7X106EQiL2WB0XLn7feL text-1.2.3.0
    unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj
    hspec-2.5.5-FvKALBd9oD63ClybuS4Bg8
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b=c22e056a410eb876f6f97788d58417ce
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             insert-ordered-containers-0.2.1.0-Frbrz52X4fNB7jXswOZzbv=ab6ad77325883908df0b5987a27fd4db
             lens-4.17-9Q1pWD2BrerLhuespF4bwK=ab1d1bd95dc58564867100a032286a07
             servant-0.13.0.1-G69gaOSA7cz7Xz442jerNe=7f811c6a1872a8c214787bca7e1a71c1
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             swagger2-2.2.2-7J7X106EQiL2WB0XLn7feL=d908294d11d20f93f41313f154a8ec64
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj=c333847eb697e0b9a0c6f4333fc78402
             hspec-2.5.5-FvKALBd9oD63ClybuS4Bg8=cad4f5bcf550d54ce78ae5766da03a80
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.5-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.5
id: servant-swagger-1.1.5-WibyP8PbQWEG1qPXfn9xN
key: servant-swagger-1.1.5-WibyP8PbQWEG1qPXfn9xN
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger™ is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: a640e182178f9284d5c3ab0c24327500
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-swagger-1.1.5
hs-libraries: HSservant-swagger-1.1.5-WibyP8PbQWEG1qPXfn9xN
depends:
    aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ base-4.11.1.0
    bytestring-0.10.8.2 http-media-0.7.1.3-DEqoMUzH7kXLeKubCF2x9V
    insert-ordered-containers-0.2.1.0-CB38EsSUD176ifOeHpsixl
    lens-4.17-FN9L27noKQw4oT5eFMxJrD
    servant-0.13.0.1-DvERNH4kZYz8UvSq9vuHdN
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    swagger2-2.2.2-7YMSxodgpiL5dU3tTLhLPf text-1.2.3.0
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    hspec-2.5.5-K5Y3kvTOZZF5KKyQtkTtR
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ=2dabf93ee02d5485cbe316a08ea94024
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             http-media-0.7.1.3-DEqoMUzH7kXLeKubCF2x9V=5e83f929be451e956bb1cd3fb8519c86
             insert-ordered-containers-0.2.1.0-CB38EsSUD176ifOeHpsixl=06c92589b82186c58a0322eadd648905
             lens-4.17-FN9L27noKQw4oT5eFMxJrD=9d01995e95a18f3d833dbe44dd027bc7
             servant-0.13.0.1-DvERNH4kZYz8UvSq9vuHdN=f2db06d7731896d7554f030ac945a2a0
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             swagger2-2.2.2-7YMSxodgpiL5dU3tTLhLPf=5a7045c9fffa8095f2bbd832c8d93c4d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             hspec-2.5.5-K5Y3kvTOZZF5KKyQtkTtR=d9075b84e871cc29b59edc5f135ff19a
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
